@@ -1,10 +1,13 @@
 import sys
 import time
-from PyQt5.QtGui import *
-from PyQt5.QtWidgets import *
+from PyQt5.QtGui import QTextDocument, QIcon
+from PyQt5.QtWidgets import ( QLabel, QDialog, QPushButton,
+                              QMainWindow, QApplication, QAction,
+                              QFontComboBox, QComboBox, QTextEdit,
+                              QColorDialog )
 from PyQt5 import QtCore
 from PyQt5.QtCore import Qt
-from PyQt5.QtPrintSupport import *
+from PyQt5.QtPrintSupport import QPrinter
 
 var = 0
 f = ""
@@ -410,9 +413,12 @@ class Main(QMainWindow):
         f.close()
         
     def OpenInitial(self, filename=None):
-        f = open(filename, 'r')
-        filedata = f.read()
-        self.text.setText(filedata)
+        try:
+            f = open(filename, 'r')
+            filedata = f.read()
+            self.text.setText(filedata)
+        except:
+            f = open('tmp', 'w')
         f.close()
  
     def Save(self):
@@ -658,4 +664,4 @@ def main():
     sys.exit(app.exec_())
  
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
